@@ -421,7 +421,7 @@ stac_version <- function(x, ...) {
 #'  the result of \code{/stac/search}, \code{/collections/{collectionId}/items}.
 #'
 #' @param assets_names        a \code{character} with the assets names to be
-#'  filtered.
+#'  filtered. If \code{NULL} (default) all assets will be returned.
 #'
 #' @param sort                a \code{logical} if true the dates will be sorted
 #'  in increasing order. By default, the dates are sorted.
@@ -435,7 +435,7 @@ stac_version <- function(x, ...) {
 #' @examples
 #' \donttest{
 #' # STACItemCollection object
-#' stac_item <- stac("http://brazildatacube.dpi.inpe.br/stac/") %>%
+#' stac_item <- stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
 #'  stac_search(collections = "CB4_64_16D_STK-1", limit = 100,
 #'         datetime = "2017-08-01/2018-03-01",
 #'         bbox = c(-48.206,-14.195,-45.067,-12.272)) %>%
@@ -445,13 +445,14 @@ stac_version <- function(x, ...) {
 #' }
 #'
 #' @export
-assets_list <- function(items, assets_names, sort = TRUE,
+assets_list <- function(items, assets_names = NULL, sort = TRUE,
                         gdal_vsi_resolution = TRUE) {
 
+  if (is.null(assets_names))
+    assets_names <- items_fields(items, "assets")
 
   timeline <- items_reap(items, field = c("properties", "datetime"))
   index    <- seq_along(timeline)
-
   if (sort) index <- order(timeline)
 
   timeline <- timeline[index]
@@ -506,7 +507,7 @@ assets_list <- function(items, assets_names, sort = TRUE,
 #' @examples
 #' \donttest{
 #' # STACItemCollection object
-#' stac_item <- stac("http://brazildatacube.dpi.inpe.br/stac/") %>%
+#' stac_item <- stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
 #'  stac_search(collections = "CB4_64_16D_STK-1", limit = 100,
 #'         datetime = "2017-08-01/2018-03-01",
 #'         bbox = c(-48.206,-14.195,-45.067,-12.272)) %>%
@@ -559,7 +560,7 @@ items_reap <- function(items, ..., field = NULL) {
 #' @examples
 #' \donttest{
 #' # STACItemCollection object
-#' stac_item <- stac("http://brazildatacube.dpi.inpe.br/stac/") %>%
+#' stac_item <- stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
 #'  stac_search(collections = "CB4_64_16D_STK-1", limit = 10,
 #'         datetime = "2017-08-01/2018-03-01") %>%
 #'  get_request()
@@ -609,7 +610,7 @@ items_fields <- function(items, ..., field = NULL) {
 #' @examples
 #' \donttest{
 #' # STACItemCollection object
-#' stac_item <- stac("http://brazildatacube.dpi.inpe.br/stac/") %>%
+#' stac_item <- stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
 #'  stac_search(collections = "CB4_64_16D_STK-1", limit = 100,
 #'         datetime = "2017-08-01/2018-03-01",
 #'         bbox = c(-48.206,-14.195,-45.067,-12.272)) %>%
